# Initialiser StyleLint dans une optique d’écoconception

## Prérequis

### Avoir initialisé votre `package.json`

```
npm init -y
```

## Installation des dépendances

### Installer StyleLint

```
npm install --save-dev stylelint
```

Pour l’instant, aucune règle n’est activée. Pour cela il faut spécifier une à une les règles qu’on souhaite activer dans un fichier `.stylelintrc.json`.

Une manière plus simple pour ajouter des groupes de règles est d’installer une configuration pour StyleLint qui activera un ensemble de règle.

### Installer la configuration standard de StyleLint

La [configuration standard](https://github.com/stylelint/stylelint-config-standard) étends la [configuration recommandée](https://github.com/stylelint/stylelint-config-recommended) de StyleLint.

Elle active les règles `stylistic issues` en plus des règles `possible errors`.

Si vous ne souhaitez pas linter les erreurs stylistiques, installez `stylelint-config-recommended`.

```
npm install --save-dev stylelint-config-standard
```

Créer une fichier `.stylelintrc.json` à la racine de votre projet et compléter le avec :

```
{
  "extends": "stylelint-config-standard"
}
```

### Installer des plugins

`stylelint-group-selectors` est un plugin pour grouper les sélecteurs qui ont les mêmes propriétés avec les même valeurs.

```
npm install --save-dev stylelint-group-selectors
```

Compléter votre `.stylelintrc.json` avec :

```
{
	...
  "plugins": [
    "stylelint-group-selectors"
  ],
  "rules": {
    "plugin/stylelint-group-selectors": true
  }
}
```

### Activer des règles supplémentaires

```
{
	...
  "rules": {
		...

    "declaration-block-no-duplicate-properties": true,
    "shorthand-property-no-redundant-values": true,
    "declaration-block-no-redundant-longhand-properties": true,
    "selector-max-compound-selectors": 3
  }
}
```

Les règles précédentes sont des règles de StyleLint qui ne sont pas activées par la configuration standard mais qui permettent d’éviter quelques redondances de code et ainsi allégé votre fichier final.

Vous pouvez ainsi ajouter des règles à votre guise ou en désactiver.
